@@ -1,6 +1,11 @@
-from sqlalchemy.exc import NoResultFound, IntegrityError, SQLAlchemyError
+from sqlalchemy.exc import NoResultFound, IntegrityError, SQLAlchemyError, MultipleResultsFound
 
-from assimilator.core.database.exceptions import DataLayerError, NotFoundError, InvalidQueryError
+from assimilator.core.database.exceptions import (
+    DataLayerError,
+    NotFoundError,
+    InvalidQueryError,
+    MultipleResultsError,
+)
 from assimilator.core.patterns.error_wrapper import ErrorWrapper
 
 
@@ -10,6 +15,7 @@ class AlchemyErrorWrapper(ErrorWrapper):
             NoResultFound: NotFoundError,
             IntegrityError: InvalidQueryError,
             SQLAlchemyError: DataLayerError,
+            MultipleResultsFound: MultipleResultsError,
         }, default_error=DataLayerError)
 
 
