@@ -10,3 +10,7 @@ class NotFoundError(DataLayerError):
 
 class InvalidQueryError(DataLayerError):
     """ The query to the data storage supplied was invalid """
+
+
+class MultipleResultsError(InvalidQueryError):
+    """ Repository get() function returned more than one result """
