@@ -1,13 +1,20 @@
 from typing import Type, Union, Optional, TypeVar, List
 
-from assimilator.internal.database.models import InternalModel
 from assimilator.core.patterns.error_wrapper import ErrorWrapper
 from assimilator.internal.database.error_wrapper import InternalErrorWrapper
-from assimilator.core.database import Repository, SpecificationType, LazyCommand, \
-    make_lazy, InvalidQueryError
+from assimilator.core.database import (
+    Repository,
+    SpecificationType,
+    LazyCommand,
+    InvalidQueryError,
+    BaseModel,
+    NotFoundError,
+)
 from assimilator.internal.database.specifications import InternalSpecificationList
+from assimilator.core.database import MultipleResultsError
+from internal.database.models_utils import dict_to_models
 
-ModelT = TypeVar("ModelT", bound=InternalModel)
+ModelT = TypeVar("ModelT", bound=BaseModel)
 
 
 class InternalRepository(Repository):
@@ -30,7 +37,6 @@ class InternalRepository(Repository):
             error_wrapper=error_wrapper or InternalErrorWrapper(),
         )
 
-    @make_lazy
     def get(
         self,
         *specifications: SpecificationType,
@@ -38,31 +44,46 @@ class InternalRepository(Repository):
         initial_query: Optional[str] = None,
     ) -> Union[LazyCommand[ModelT], ModelT]:
         query = self._apply_specifications(
-            query=self.get_initial_query(initial_query),
+            query=initial_query,
             specifications=specifications,
         )
-        return self.session[query]
 
-    @make_lazy
+        if query:   # Dict key was not provided, we must use other search parameters
+            return self.session[query]
+
+        found_models = list(self._apply_specifications(
+            query=self.session.values(),
+            specifications=specifications,
+        ))
+
+        if not found_models:
+            raise NotFoundError()
+        elif len(found_models) != 1:
+            raise MultipleResultsError()
+
+        return found_models[0]
+
     def filter(
         self,
         *specifications: SpecificationType,
         lazy: bool = False,
         initial_query: Optional[str] = None,
     ) -> Union[LazyCommand[List[ModelT]], List[ModelT]]:
-        return self._apply_specifications(
-            query=list(self.session.values()),
+        return list(self._apply_specifications(
+            query=self.session.values(),
             specifications=specifications,
-        )
+        ))
 
     def save(self, obj: Optional[ModelT] = None, **obj_data) -> ModelT:
         if obj is None:
-            obj = self.model(**obj_data)
+            obj = self.model(**dict_to_models(data=obj_data, model=self.model))
 
         self.session[obj.id] = obj
         return obj
 
     def delete(self, obj: Optional[ModelT] = None, *specifications: SpecificationType) -> None:
+        obj, specifications = self._check_obj_is_specification(obj, specifications)
+
         if specifications:
             for model in self.filter(*specifications, lazy=True):
                 del self.session[model.id]
@@ -70,8 +91,13 @@ class InternalRepository(Repository):
             del self.session[obj.id]
 
     def update(
-        self, obj: Optional[ModelT] = None, *specifications: SpecificationType, **update_values,
+        self,
+        obj: Optional[ModelT] = None,
+        *specifications: SpecificationType,
+        **update_values,
     ) -> None:
+        obj, specifications = self._check_obj_is_specification(obj, specifications)
+
         if specifications:
             if not update_values:
                 raise InvalidQueryError(
@@ -93,12 +119,17 @@ class InternalRepository(Repository):
         fresh_obj = self.get(self.specs.filter(id=obj.id), lazy=False)
         obj.__dict__.update(fresh_obj.__dict__)
 
-    @make_lazy
     def count(
-        self, *specifications: SpecificationType, lazy: bool = False,
+        self,
+        *specifications: SpecificationType,
+        lazy: bool = False,
+        initial_query: Optional[str] = None,
     ) -> Union[LazyCommand[int], int]:
         if specifications:
-            return len(self.filter(*specifications, lazy=False))
+            return len(list(self._apply_specifications(  # We do not call filter() for list() optimization
+                query=self.session.values(),
+                specifications=specifications,
+            )))
         return len(self.session)
 
 
